==> content_model_documentation-1.0.17.tar.gz: content_model_documentation/src/Report/EnabledModules.php <==
<?php

namespace Drupal\content_model_documentation\Report;

use Drupal\content_model_documentation\CMDocumentConnectorTrait;
use Drupal\content_model_documentation\DocumentableModules;
use Drupal\content_model_documentation\FieldsReportManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Http\RequestStack;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A report that shows all node content types and their counts.
 */
class EnabledModules extends ReportBase implements ReportInterface, ReportTableInterface {

  use CMDocumentConnectorTrait;
  use StringTranslationTrait;

  /**
   * The DocumentableModules service.
   *
   * @var Drupal\content_model_documentation\DocumentableModules
   */
  protected $documentableModules;

  /**
   * Constructor for report base.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity type manager.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer.
   * @param \Drupal\Core\Http\RequestStack $request_stack
   *   The symfony request stack.
   * @param \Drupal\content_model_documentation\FieldsReportManagerInterface $field_report_manager
   *   The field report manager.
   * @param \Drupal\content_model_documentation\DocumentableModules $documentable_modules
   *   The documentable modules service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    Connection $database,
    EntityTypeManagerInterface $entity_type_manager,
    LanguageManagerInterface $language_manager,
    RendererInterface $renderer,
    RequestStack $request_stack,
    FieldsReportManagerInterface $field_report_manager,
    DocumentableModules $documentable_modules
    ) {
    parent::__construct($config_factory, $database, $entity_type_manager, $language_manager, $renderer, $request_stack, $field_report_manager);
    $this->documentableModules = $documentable_modules;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Unfortunately the list gets pretty long because the child classes
    // would have to fully override parent. The create() functions can't be
    // chained like the __constructor() functions can.
    return new static(
      // These are the ReportBase arguments.
      $container->get('config.factory'),
      $container->get('database'),
      $container->get('entity_type.manager'),
      $container->get('language_manager'),
      $container->get('renderer'),
      $container->get('request_stack'),
      $container->get('content_model_documentation.fields_report'),
      // These are the arguments custom to this report.
      $container->get('content_model_documentation.documentable.modules'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getReportTitle(): string {
    return 'Enabled modules';
  }

  /**
   * {@inheritdoc}
   */
  public function getReportType(): string {
    return 'table';
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getCaption(): string {
    return $this->t('This is list of all the enabled modules on the site, with links to help and documentation.');
  }

  /**
   * {@inheritdoc}
   */
  public function getHeaderRow(): array {
    $header = [
      $this->t('Module name'),
      $this->t('Machine name'),
      $this->t('Description'),
      $this->t('Project'),
      $this->t('Help'),
    ];
    if ($this->config->get('modules')) {
      array_push($header, $this->t('Documentation'));
    }
    return $header;
  }

  /**
   * {@inheritdoc}
   */
  public function getTableBodyRows(): array {
    $rows = $this->documentableModules->getEnabledReporting();

    return $rows;
  }

  /**
   * {@inheritdoc}
   */
  public function getCsvBodyRows(): array {
    // Will need to convert links to urls.
    $site_address = $this->requestStack->getCurrentRequest()->getSchemeAndHttpHost();
    $rows = $this->documentableModules->getEnabledReporting(TRUE, $site_address);
    return $rows;
  }

}

==> content_model_documentation-1.0.18.tar.gz: content_model_documentation/src/Report/EnabledModules.php <==
<?php

namespace Drupal\content_model_documentation\Report;

use Drupal\content_model_documentation\CMDocumentConnectorTrait;
use Drupal\content_model_documentation\DocumentableModules;
use Drupal\content_model_documentation\FieldsReportManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * A report that shows all node content types and their counts.
 */
class EnabledModules extends ReportBase implements ReportInterface, ReportTableInterface {

  use CMDocumentConnectorTrait;
  use StringTranslationTrait;

  /**
   * The DocumentableModules service.
   *
   * @var Drupal\content_model_documentation\DocumentableModules
   */
  protected $documentableModules;

  /**
   * Constructor for report base.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity type manager.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The symfony request stack.
   * @param \Drupal\content_model_documentation\FieldsReportManagerInterface $field_report_manager
   *   The field report manager.
   * @param \Drupal\content_model_documentation\DocumentableModules $documentable_modules
   *   The documentable modules service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    Connection $database,
    EntityTypeManagerInterface $entity_type_manager,
    LanguageManagerInterface $language_manager,
    RendererInterface $renderer,
    RequestStack $request_stack,
    FieldsReportManagerInterface $field_report_manager,
    DocumentableModules $documentable_modules
    ) {
    parent::__construct($config_factory, $database, $entity_type_manager, $language_manager, $renderer, $request_stack, $field_report_manager);
    $this->documentableModules = $documentable_modules;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Unfortunately the list gets pretty long because the child classes
    // would have to fully override parent. The create() functions can't be
    // chained like the __constructor() functions can.
    return new static(
      // These are the ReportBase arguments.
      $container->get('config.factory'),
      $container->get('database'),
      $container->get('entity_type.manager'),
      $container->get('language_manager'),
      $container->get('renderer'),
      $container->get('request_stack'),
      $container->get('content_model_documentation.fields_report'),
      // These are the arguments custom to this report.
      $container->get('content_model_documentation.documentable.modules'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getReportTitle(): string {
    return 'Enabled modules';
  }

  /**
   * {@inheritdoc}
   */
  public function getReportType(): string {
    return 'table';
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getCaption(): string {
    return $this->t('This is list of all the enabled modules on the site, with links to help and documentation.');
  }

  /**
   * {@inheritdoc}
   */
  public function getHeaderRow(): array {
    $header = [
      $this->t('Module name'),
      $this->t('Machine name'),
      $this->t('Description'),
      $this->t('Project'),
      $this->t('Help'),
    ];
    if ($this->config->get('modules')) {
      array_push($header, $this->t('Documentation'));
    }
    return $header;
  }

  /**
   * {@inheritdoc}
   */
  public function getTableBodyRows(): array {
    $rows = $this->documentableModules->getEnabledReporting();

    return $rows;
  }

  /**
   * {@inheritdoc}
   */
  public function getCsvBodyRows(): array {
    // Will need to convert links to urls.
    $site_address = $this->requestStack->getCurrentRequest()->getSchemeAndHttpHost();
    $rows = $this->documentableModules->getEnabledReporting(TRUE, $site_address);
    return $rows;
  }

}
